import Mixin from '@ember/object/mixin';
import { Headers } from '../../-private/types';
interface JsonApiErrorObject {
    title: string;
    status: string;
    detail?: any;
}
declare const _default: Mixin<{
    /**
     * Normalize the error from the server into the same format
     *
     * The format we normalize to is based on the JSON API specification.  The
     * return value should be an array of objects that match the format they
     * describe. More details about the object format can be found
     * [here](http://jsonapi.org/format/#error-objects)
     *
     * The basics of the format are as follows:
     *
     * ```javascript
     * [
     *   {
     *     status: 'The status code for the error',
     *     title: 'The human-readable title of the error'
     *     detail: 'The human-readable details of the error'
     *   }
     * ]
     * ```
     *
     * In cases where the server returns an array, then there should be one item
     * in the array for each of the payload.  If your server returns a JSON API
     * formatted payload already, it will just be returned directly.
     *
     * If your server returns something other than a JSON API format, it's
     * suggested that you override this method to convert your own errors into the
     * one described above.
     */
    normalizeErrorResponse(status: number, _headers: Headers, payload?: any): JsonApiErrorObject[];
}, import("@ember/object").default>;
export default _default;
